from django import forms
from django.contrib.auth.forms import UserCreationForm
from .models import User, Transportasi

class RegisterForm(UserCreationForm):
    birthdate = forms.DateField(widget=forms.DateInput(attrs={'type': 'date'}))
    phone_number = forms.CharField(max_length=15)
    blog_url = forms.URLField(required=False)
    bio = forms.CharField(widget=forms.Textarea, required=False)
    lokasi_duduk = forms.ChoiceField(choices=[("Jendela", "Jendela"), ("Tengah", "Tengah"), ("Gang", "Gang")])
    nomor_rangka = forms.CharField(max_length=50)

    class Meta:
        model = User
        fields = ["username", "email", "password1", "password2", "birthdate", "phone_number", "blog_url", "bio"]

    def save(self, commit=True):
        user = super().save(commit=False)
        if commit:
            user.save()
            transportasi = Transportasi.objects.create(
                lokasi_duduk=self.cleaned_data['lokasi_duduk'],
                nomor_rangka=self.cleaned_data['nomor_rangka']
            )
            user.transportasi = transportasi
            user.save()
        return user
