import re
from django.forms import ValidationError
from django.http import JsonResponse
from django.shortcuts import render, redirect
from django.contrib import messages
from django.contrib.auth import authenticate, login, logout
from .models import User, Transportasi
from datetime import datetime


# Home Page
def home(request):
    return render(request, 'main.html')


def login_page(request):
    if request.method == "POST":
        username = request.POST.get('username')
        password = request.POST.get('password')

        # Autentikasi pengguna
        user = authenticate(username=username, password=password)
        if user is None:
            messages.error(request, "Invalid username or password")
            return redirect('login')  

   
        login(request, user)

        if user.is_superuser:
            return redirect('/admin/')  
        return redirect('user-page')  

    return render(request, 'login.html')

# Register Page
def register_page(request):
    if request.method == 'POST':
        username = request.POST.get('username')
        email = request.POST.get('email')
        password = request.POST.get('password')
        birthdate_str = request.POST.get('birthdate')
        phone_number = request.POST.get('phone_number')
        blog_url = request.POST.get('blog_url')
        bio = request.POST.get('bio')
        lokasi_duduk = request.POST.get('lokasi_duduk')
        nomor_rangka = request.POST.get('nomor_rangka')

        try:
            birthdate = datetime.strptime(birthdate_str, "%Y-%m-%d").date()
        except ValueError:
            return render(request, 'register.html', {"form_errors": {"birthdate": "Invalid birthdate format!"}})

        errors = {}

        if User.objects.filter(username=username).exists():
            errors['username'] = "Username already taken!"
        if User.objects.filter(email=email).exists():
            errors['email'] = "Email already registered!"

        user = User(
            username=username,
            email=email,
            birthdate=birthdate,
            phone_number=phone_number,
            blog_url=blog_url,
            bio=bio
        )
        user.set_password(password) 

        try:
            user.full_clean() 
        except ValidationError as e:
            for field, error_list in e.message_dict.items():
                errors[field] = error_list[0] 

        # Validasi transportasi
        transportasi = Transportasi(lokasi_duduk=lokasi_duduk, nomor_rangka=nomor_rangka)
        try:
            transportasi.full_clean()
        except ValidationError as e:
            for field, error_list in e.message_dict.items():
                errors[field] = error_list[0]  

        if errors:
            return render(request, 'register.html', {"form_errors": errors})

        transportasi.save()
        user.set_password(password)
        user.transportasi = transportasi
        user.save()

        messages.success(request, "Account created successfully!")
        return redirect('/login/')

    return render(request, 'register.html', {"form_errors": {}})


# Logout
def logout_page(request):
    logout(request)
    messages.success(request, "Logout successful.")
    return redirect('/login/')


def user_page(request):
    return render(request, 'user_page.html')



